@@ -26,7 +26,7 @@
 
 int init (void);
 
-static inline void
+static void
 conv_rgba8_cairo24_le (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
@@ -44,7 +44,7 @@ conv_rgba8_cairo24_le (const Babl *conversion,unsigned char *src, unsigned char
     }
 }
 
-static inline void
+static void
 conv_rgb8_cairo24_le (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
@@ -63,7 +63,7 @@ conv_rgb8_cairo24_le (const Babl *conversion,unsigned char *src, unsigned char *
 }
 
 #if 0
-static inline void
+static void
 conv_rgbA8_premul_cairo32_le (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
@@ -82,7 +82,7 @@ conv_rgbA8_premul_cairo32_le (const Babl *conversion,unsigned char *src, unsigne
 }
 #else
 
-static inline void
+static void
 conv_rgbA8_premul_cairo32_le (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
@@ -137,26 +137,24 @@ static void conv_cairo32_rgbAF_premul_le (const Babl *conversion,unsigned char *
     }
 }
 
-static inline void
-conv_rgbA8_cairo32_le (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgba8_cairo32_le (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
+  uint32_t *dsti = (void*) dst;
   while (n--)
     {
-      unsigned char red    = *src++;
-      unsigned char green  = *src++;
-      unsigned char blue   = *src++;
-      unsigned char alpha  = *src++;
-
+      unsigned char alpha  = src[3];
 #define div_255(a) ((((a)+128)+(((a)+128)>>8))>>8)
-      *dst++ = div_255 (blue  * alpha);
-      *dst++ = div_255 (green * alpha);
-      *dst++ = div_255 (red   * alpha);
-      *dst++ = alpha;
+      *dsti++ = (alpha << 24) +
+                (div_255 (src[0] * alpha) << 16) +
+                (div_255 (src[1] * alpha) << 8) +
+                (div_255 (src[2] * alpha));
+      src+=4;
     }
 }
 
-static inline void
+static void
 conv_rgb8_cairo32_le (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
@@ -176,7 +174,7 @@ conv_rgb8_cairo32_le (const Babl *conversion,unsigned char *src, unsigned char *
 
 
 
-static inline void
+static void
 conv_yA8_cairo32_le (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
@@ -195,7 +193,7 @@ conv_yA8_cairo32_le (const Babl *conversion,unsigned char *src, unsigned char *d
     }
 }
 
-static inline void
+static void
 conv_yA16_cairo32_le (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
@@ -212,7 +210,7 @@ conv_yA16_cairo32_le (const Babl *conversion,unsigned char *src, unsigned char *
     }
 }
 
-static inline void
+static void
 conv_y8_cairo32_le (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
@@ -226,7 +224,7 @@ conv_y8_cairo32_le (const Babl *conversion,unsigned char *src, unsigned char *ds
     }
 }
 
-static inline void
+static void
 conv_y16_cairo32_le (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
@@ -398,7 +396,7 @@ init (void)
                            conv_rgbA8_premul_cairo32_le, NULL);
 
       babl_conversion_new (babl_format ("R'G'B'A u8"), f32, "linear",
-                           conv_rgbA8_cairo32_le, NULL);
+                           conv_rgba8_cairo32_le, NULL);
 
 
       babl_conversion_new (babl_format ("R'G'B' u8"), f32, "linear",
