@@ -411,20 +411,15 @@ static void
 conv_rgbF_rgbaF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
+  float *fsrc = (void*) src;
+  float *fdst = (void*) dst;
 
   while (n--)
     {
-      *(uint32_t *) dst = (*(uint32_t *) src);
-      src           += 4;
-      dst           += 4;
-      *(uint32_t *) dst = (*(uint32_t *) src);
-      src           += 4;
-      dst           += 4;
-      *(uint32_t *) dst = (*(uint32_t *) src);
-      src           += 4;
-      dst           += 4;
-      *(float *) dst = 1.0;
-      dst           += 4;
+      *fdst++ = *fsrc++;
+      *fdst++ = *fsrc++; 
+      *fdst++ = *fsrc++;
+      *fdst++ = 1.0f;
     }
 }
 
@@ -484,6 +479,37 @@ conv_gF_rgbF (const Babl *conversion,unsigned char *src, unsigned char *dst, lon
     }
 }
 
+static void
+conv_g8_rgb8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
+{
+  long n = samples;
+
+  while (n--)
+    {
+      dst[0]=*src;
+      dst[1]=*src;
+      dst[2]=*src;
+      dst += 3;
+      src += 1;
+    }
+}
+#define conv_g8_rgbA8  conv_g8_rgba8
+static void
+conv_g8_rgba8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
+{
+  long n = samples;
+
+  while (n--)
+    {
+      dst[0]=*src;
+      dst[1]=*src;
+      dst[2]=*src;
+      dst[3]=255;
+      dst += 4;
+      src += 1;
+    }
+}
+
 static void
 conv_gaF_rgbaF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
@@ -543,7 +569,12 @@ conv_rgbaF_rgb16 (const Babl *conversion,unsigned char *src, unsigned char *dst,
 
       for (c = 0; c < 3; c++)
         {
-          *(unsigned short *) dst = lrint ((*(float *) src) * 65535.0);
+          if ((*(float *) src) >= 1.0)
+            *(unsigned short *) dst = 65535;
+          else if ((*(float *) src) <=0)
+            *(unsigned short *) dst = 0;
+          else
+            *(unsigned short *) dst = lrint ((*(float *) src) * 65535.0);
           dst                    += 2;
           src                    += 4;
         }
@@ -1062,6 +1093,9 @@ init (void)
   o (ga8, gaF);
   o (gA8, gAF);
   o (g8, gF);
+  o (g8, rgb8);
+  o (g8, rgba8);
+  o (g8, rgbA8);
   o (gaF, ga16);
   o (gAF, gA16);
   o (gF, g16);
