@@ -22,37 +22,53 @@
 #include "config.h"
 #include <stdio.h>
 
-#include "babl.h"
+#include "babl-internal.h"
 
 #include "base/util.h"
 #include "extensions/util.h"
 
-#define INLINE    inline
-
 
 /* lookup tables used in conversion */
 
+#define MAX_SPACES 32
+static const Babl *spaces[MAX_SPACES]={NULL,};
+
 static float lut_linear[1 << 8];
-static float lut_gamma_2_2[1 << 8];
+static float lut_gamma_2_2[MAX_SPACES][1 << 8];
 
 
-static void
-tables_init (void)
+static int
+tables_init (const Babl *space)
 {
-  int i;
+  int i, j;
+
+  for (j = 0; spaces[j]; j++)
+  {
+    if (spaces[j] == space)
+      return j;
+  }
+  spaces[j] = space;
+
+  /* fill tables for conversion from 8 bit integer to float */
+  if (j == 0)
+  for (i = 0; i < 1 << 8; i++)
+    {
+      double value = i / 255.0;
+      lut_linear[i]    = value;
+    }
 
   /* fill tables for conversion from 8 bit integer to float */
   for (i = 0; i < 1 << 8; i++)
     {
       double value = i / 255.0;
-
-      lut_linear[i]    = value;
-      lut_gamma_2_2[i] = gamma_2_2_to_linear (value);
+      lut_gamma_2_2[j][i] = babl_trc_to_linear (space->space.trc[0], value);
     }
+
+  return j;
 }
 
-static INLINE long
-u8_linear_to_float_linear (unsigned char *src,
+static inline void
+u8_linear_to_float_linear (const Babl *conversion,unsigned char *src,
                            unsigned char *dst,
                            long           samples)
 {
@@ -61,13 +77,11 @@ u8_linear_to_float_linear (unsigned char *src,
 
   while (n--)
     *d++ = lut_linear[*src++];
-
-  return samples;
 }
 
 
-static INLINE long
-u8_linear_to_float_linear_premul (unsigned char *src,
+static void
+u8_linear_to_float_linear_premul (const Babl *conversion,unsigned char *src,
                                   unsigned char *dst,
                                   long           samples)
 {
@@ -84,85 +98,74 @@ u8_linear_to_float_linear_premul (unsigned char *src,
       src += 4;
       d += 4;
     }
-  return samples;
 }
 
-static INLINE long
-u8_gamma_2_2_to_float_linear (unsigned char *src,
+static inline void
+u8_gamma_2_2_to_float_linear (const Babl *conversion,unsigned char *src,
                               unsigned char *dst,
                               long           samples)
 {
+  int   space_no = tables_init (conversion->conversion.source->format.space);
   float *d = (float *) dst;
   long   n = samples;
 
   while (n--)
-    *d++ = lut_gamma_2_2[*src++];
-
-  return samples;
+    *d++ = lut_gamma_2_2[space_no][*src++];
 }
 
-static INLINE long
-conv_rgba8_linear_rgbaF_linear (unsigned char *src,
+static void
+conv_rgba8_linear_rgbaF_linear (const Babl *conversion,unsigned char *src,
                                 unsigned char *dst,
                                 long           samples)
 {
-  u8_linear_to_float_linear (src, dst, samples * 4);
-
-  return samples;
+  u8_linear_to_float_linear (conversion, src, dst, samples * 4);
 }
 
-static INLINE long
-conv_rgba8_linear_ragabaaF_linear (unsigned char *src,
+static void
+conv_rgba8_linear_ragabaaF_linear (const Babl *conversion,unsigned char *src,
                                 unsigned char *dst,
                                 long           samples)
 {
-  u8_linear_to_float_linear_premul (src, dst, samples);
-
-  return samples;
+  u8_linear_to_float_linear_premul (conversion, src, dst, samples);
 }
 
 
-static INLINE long
-conv_rgba8_gamma_2_2_rgbaF_linear (unsigned char *src,
+static void
+conv_rgba8_gamma_2_2_rgbaF_linear (const Babl *conversion,unsigned char *src,
                                    unsigned char *dst,
                                    long           samples)
 {
+  int   space_no = tables_init (conversion->conversion.source->format.space);
   float *d = (float *) dst;
   long   n = samples;
 
   while (n--)
     {
-      *d++ = lut_gamma_2_2[*src++];
-      *d++ = lut_gamma_2_2[*src++];
-      *d++ = lut_gamma_2_2[*src++];
+      *d++ = lut_gamma_2_2[space_no][*src++];
+      *d++ = lut_gamma_2_2[space_no][*src++];
+      *d++ = lut_gamma_2_2[space_no][*src++];
       *d++ = lut_linear[*src++];
     }
-
-  return samples;
 }
 
-static INLINE long
-conv_rgb8_linear_rgbF_linear (unsigned char *src,
+static void
+conv_rgb8_linear_rgbF_linear (const Babl *conversion,unsigned char *src,
                               unsigned char *dst,
                               long           samples)
 {
-  u8_linear_to_float_linear (src, dst, samples * 3);
-
-  return samples;
+  u8_linear_to_float_linear (conversion, src, dst, samples * 3);
 }
 
-static INLINE long
-conv_rgb8_gamma_2_2_rgbF_linear (unsigned char *src,
+static void
+conv_rgb8_gamma_2_2_rgbF_linear (const Babl *conversion,unsigned char *src,
                                  unsigned char *dst,
                                  long           samples)
 {
-  u8_gamma_2_2_to_float_linear (src, dst, samples * 3);
-
-  return samples;
+  u8_gamma_2_2_to_float_linear (conversion, src, dst, samples * 3);
 }
 
-static INLINE long
-conv_rgb8_linear_rgbaF_linear (unsigned char *src,
+static void
+conv_rgb8_linear_rgbaF_linear (const Babl *conversion,unsigned char *src,
                                unsigned char *dst,
                                long           samples)
 {
@@ -176,60 +179,54 @@ conv_rgb8_linear_rgbaF_linear (unsigned char *src,
       *d++ = lut_linear[*src++];
       *d++ = 1.0;
     }
-
-  return samples;
 }
 
 #define conv_rgb8_linear_ragabaaF_linear conv_rgb8_linear_rgbaF_linear
 
-static INLINE long
-conv_rgb8_gamma_2_2_rgbaF_linear (unsigned char *src,
+static void
+conv_rgb8_gamma_2_2_rgbaF_linear (const Babl *conversion,unsigned char *src,
                                   unsigned char *dst,
                                   long           samples)
 {
+  int   space_no = tables_init (conversion->conversion.source->format.space);
   float *d = (float *) dst;
   long   n = samples;
 
   while (n--)
     {
-      *d++ = lut_gamma_2_2[*src++];
-      *d++ = lut_gamma_2_2[*src++];
-      *d++ = lut_gamma_2_2[*src++];
+      *d++ = lut_gamma_2_2[space_no][*src++];
+      *d++ = lut_gamma_2_2[space_no][*src++];
+      *d++ = lut_gamma_2_2[space_no][*src++];
       *d++ = 1.0;
     }
-
-  return samples;
 }
 
-static INLINE long
-conv_ga8_linear_gaF_linear (unsigned char *src,
+static void
+conv_ga8_linear_gaF_linear (const Babl *conversion,unsigned char *src,
                             unsigned char *dst,
                             long           samples)
 {
-  u8_linear_to_float_linear (src, dst, samples * 2);
-
-  return samples;
+  u8_linear_to_float_linear (conversion, src, dst, samples * 2);
 }
 
-static INLINE long
-conv_ga8_gamma_2_2_gaF_linear (unsigned char *src,
+static void
+conv_ga8_gamma_2_2_gaF_linear (const Babl *conversion,unsigned char *src,
                                unsigned char *dst,
                                long           samples)
 {
+  int   space_no = tables_init (conversion->conversion.source->format.space);
   float *d = (float *) dst;
   long   n = samples;
 
   while (n--)
     {
-      *d++ = lut_gamma_2_2[*src++];
+      *d++ = lut_gamma_2_2[space_no][*src++];
       *d++ = lut_linear[*src++];
     }
-
-  return samples;
 }
 
-static INLINE long
-conv_ga8_gamma_2_2_rgba8_gamma_2_2 (unsigned char *src,
+static void
+conv_ga8_gamma_2_2_rgba8_gamma_2_2 (const Babl *conversion,unsigned char *src,
                                     unsigned char *dst,
                                     long           samples)
 {
@@ -242,12 +239,10 @@ conv_ga8_gamma_2_2_rgba8_gamma_2_2 (unsigned char *src,
       *dst++ = *src++;
       *dst++ = *src++;
     }
-
-  return samples;
 }
 
-static INLINE long
-conv_ga8_linear_rgbaF_linear (unsigned char *src,
+static void
+conv_ga8_linear_rgbaF_linear (const Babl *conversion,unsigned char *src,
                               unsigned char *dst,
                               long           samples)
 {
@@ -263,53 +258,46 @@ conv_ga8_linear_rgbaF_linear (unsigned char *src,
       *d++ = value;
       *d++ = lut_linear[*src++];
     }
-
-  return samples;
 }
 
-static INLINE long
-conv_ga8_gamma_2_2_rgbaF_linear (unsigned char *src,
+static void
+conv_ga8_gamma_2_2_rgbaF_linear (const Babl *conversion,unsigned char *src,
                                  unsigned char *dst,
                                  long           samples)
 {
+  int   space_no = tables_init (conversion->conversion.source->format.space);
   float *d = (float *) dst;
   long   n = samples;
 
   while (n--)
     {
-      float value = lut_gamma_2_2[*src++];
+      float value = lut_gamma_2_2[space_no][*src++];
 
       *d++ = value;
       *d++ = value;
       *d++ = value;
       *d++ = lut_linear[*src++];
     }
-
-  return samples;
 }
 
-static INLINE long
-conv_g8_linear_gF_linear (unsigned char *src,
+static void
+conv_g8_linear_gF_linear (const Babl *conversion,unsigned char *src,
                           unsigned char *dst,
                           long           samples)
 {
-  u8_linear_to_float_linear (src, dst, samples);
-
-  return samples;
+  u8_linear_to_float_linear (conversion, src, dst, samples);
 }
 
-static INLINE long
-conv_g8_gamma_2_2_gF_linear (unsigned char *src,
+static void
+conv_g8_gamma_2_2_gF_linear (const Babl *conversion,unsigned char *src,
                              unsigned char *dst,
                              long           samples)
 {
-  u8_gamma_2_2_to_float_linear (src, dst, samples);
-
-  return samples;
+  u8_gamma_2_2_to_float_linear (conversion, src, dst, samples);
 }
 
-static INLINE long
-conv_g8_linear_rgbaF_linear (unsigned char *src,
+static void
+conv_g8_linear_rgbaF_linear (const Babl *conversion,unsigned char *src,
                              unsigned char *dst,
                              long           samples)
 {
@@ -325,33 +313,31 @@ conv_g8_linear_rgbaF_linear (unsigned char *src,
       *d++ = value;
       *d++ = 1.0;
     }
-
-  return samples;
 }
-static INLINE long
-conv_g8_gamma_2_2_rgbaF_linear (unsigned char *src,
+
+static void
+conv_g8_gamma_2_2_rgbaF_linear (const Babl *conversion,unsigned char *src,
                                 unsigned char *dst,
                                 long           samples)
 {
+  int   space_no = tables_init (conversion->conversion.source->format.space);
   float *d = (float *) dst;
   long   n = samples;
 
   while (n--)
     {
-      float value = lut_gamma_2_2[*src++];
+      float value = lut_gamma_2_2[space_no][*src++];
 
       *d++ = value;
       *d++ = value;
       *d++ = value;
       *d++ = 1.0;
     }
-
-  return samples;
 }
 
-static INLINE long
-conv_rgbaF_linear_rgb8_linear (unsigned char *src, 
-                               unsigned char *dst, 
+static void
+conv_rgbaF_linear_rgb8_linear (const Babl *conversion,unsigned char *src,
+                               unsigned char *dst,
                                long           samples)
 {
   float *fsrc = (float *) src;
@@ -365,19 +351,17 @@ conv_rgbaF_linear_rgb8_linear (unsigned char *src,
 
       v = rint (*fsrc++ * 255.0);
       *dst++ = (v < 0) ? 0 : ((v > 255) ? 255 : v);
-     
+
       v = rint (*fsrc++ * 255.0);
       *dst++ = (v < 0) ? 0 : ((v > 255) ? 255 : v);
 
       fsrc++;
     }
-
-  return samples;
 }
 
-static INLINE long
-conv_rgbaF_linear_rgba8_linear (unsigned char *src, 
-                                unsigned char *dst, 
+static void
+conv_rgbaF_linear_rgba8_linear (const Babl *conversion,unsigned char *src,
+                                unsigned char *dst,
                                 long           samples)
 {
   float *fsrc = (float *) src;
@@ -391,15 +375,13 @@ conv_rgbaF_linear_rgba8_linear (unsigned char *src,
 
       v = rint (*fsrc++ * 255.0);
       *dst++ = (v < 0) ? 0 : ((v > 255) ? 255 : v);
-     
+
       v = rint (*fsrc++ * 255.0);
       *dst++ = (v < 0) ? 0 : ((v > 255) ? 255 : v);
 
       v = rint (*fsrc++ * 255.0);
       *dst++ = (v < 0) ? 0 : ((v > 255) ? 255 : v);
     }
-
-  return samples;
 }
 
 int init (void);
@@ -494,7 +476,7 @@ init (void)
     babl_component ("Y'"),
     NULL);
 
-  tables_init ();
+  tables_init (babl_space("sRGB"));
 
 #define o(src, dst) \
   babl_conversion_new (src, dst, "linear", conv_ ## src ## _ ## dst, NULL)
